scoretools.FixedDurationContainer
=================================

.. abjad-lineage:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer

.. autoclass:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.append
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.extend
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.index
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.insert
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.is_full
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.is_misfilled
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.is_overfull
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.is_simultaneous
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.is_underfull
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.pop
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.remove
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.reverse
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.select_leaves
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.select_notes_and_chords
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.target_duration
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__contains__
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__copy__
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__delitem__
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__eq__
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__format__
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__getitem__
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__hash__
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__illustrate__
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__len__
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__mul__
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__ne__
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__repr__
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__rmul__
      ~abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__setitem__

Bases
-----

- :py:class:`scoretools.Container <abjad.tools.scoretools.Container.Container>`

- :py:class:`scoretools.Component <abjad.tools.scoretools.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.is_full
   :noindex:

.. autoattribute:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.is_misfilled
   :noindex:

.. autoattribute:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.is_overfull
   :noindex:

.. autoattribute:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.is_underfull
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.is_simultaneous
   :noindex:

.. autoattribute:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.target_duration
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.append
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.extend
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.index
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.insert
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.pop
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.remove
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.reverse
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.select_leaves
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.select_notes_and_chords
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__contains__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__copy__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__delitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__format__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__getitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__hash__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__illustrate__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__len__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.FixedDurationContainer.FixedDurationContainer.__setitem__
   :noindex:
